Trait ring::signature::VerificationAlgorithm
[−]
[src]
pub trait VerificationAlgorithm: Sync {
fn verify(&self, public_key: Input, msg: Input, signature: Input) -> Result<(), Unspecified>;
}A signature verification algorithm.
Don't implement this trait yourself. This is intended for implementation by ring types only. ring may assume there are no implementations of this trait outside the ring crate, which may cause external implementations to not work as one might expect.
Required Methods
fn verify(&self, public_key: Input, msg: Input, signature: Input) -> Result<(), Unspecified>
Verify the signature signature of message msg with the public key
public_key.
Implementors
impl VerificationAlgorithm for EdDSAParametersimpl VerificationAlgorithm for ECDSAParametersimpl VerificationAlgorithm for RSAParameters